Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LogWatcher ¶
type LogWatcher interface {
// Watch starts watching logs and returns logs via a channel.
Watch() (<-chan *types.Log, error)
// Stop stops the log watcher. Resources open should be closed properly.
Stop()
}
LogWatcher is the interface of a log watcher.
type WatcherConfig ¶
type WatcherConfig struct {
// Plugin is the name of plugin which is currently used.
// Currently supported: filelog, journald, kmsg.
Plugin string `json:"plugin,omitempty"`
// PluginConfig is a key/value configuration of a plugin. Valid configurations
// are defined in different log watcher plugin.
PluginConfig map[string]string `json:"pluginConfig,omitempty"`
// LogPath is the path to the log
LogPath string `json:"logPath,omitempty"`
// Lookback is the time log watcher looks up
Lookback string `json:"lookback,omitempty"`
// Delay is the time duration log watcher delays after node boot time. This is
// useful when the log watcher needs to wait for some time until the node
// becomes stable.
Delay string `json:"delay,omitempty"`
}
WatcherConfig is the configuration of the log watcher.
type WatcherCreateFunc ¶
type WatcherCreateFunc func(WatcherConfig) LogWatcher
WatcherCreateFunc is the create function of a log watcher.
Click to show internal directories.
Click to hide internal directories.